# vim:fileencoding=utf-8:noet
from __future__ import (unicode_literals, division, absolute_import, print_function)

__version__ = "2.8.3"

def get_version():
	return __version__
